/*******************************************************************************
  Main Source File

  Company:
    Microchip Technology Inc.

  File Name:
    main.c

  Summary:
    This file contains the "main" function for a project.

  Description:
    This file contains the "main" function for a project.  The
    "main" function calls the "SYS_Initialize" function to initialize the state
    machines of all modules in the system
 *******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************

#include <stddef.h>                     // Defines NULL
#include <stdbool.h>                    // Defines true
#include <stdlib.h>                     // Defines EXIT_FAILURE
#include <stdio.h>
#include <string.h>
#include "definitions.h"                // SYS function prototypes

static volatile bool    isRTCTimerExpired = false;
static volatile bool    isUSARTTxComplete = false;
static uint8_t          uartTxBuffer[30] = {0};
static unsigned char    SERCOM_LoopCounter = 0 ;

static void rtcEventHandler (RTC_TIMER32_INT_MASK intCause, uintptr_t context)
{
    if (intCause & RTC_TIMER32_INT_MASK_COMPARE_MATCH)
    {
        /* RTC timer compare match. Here -----> Step #5 */
        isRTCTimerExpired = true;
    }
}

static void usartTxHandler( uintptr_t context )
{
    isUSARTTxComplete = true;
}


// *****************************************************************************
// *****************************************************************************
// Section: Main Entry Point
// *****************************************************************************
// *****************************************************************************

int main ( void )
{
    /* Initialize all modules */
    SYS_Initialize ( NULL );
    
    SERCOM0_USART_WriteCallbackRegister(usartTxHandler, 0);
    RTC_Timer32CallbackRegister(rtcEventHandler, 0);
    RTC_Timer32Start();

    while ( true )
    {
        bool status;
        /* Maintain state machines of all polled MPLAB Harmony modules. */
        SYS_Tasks ( );
        
        if (isRTCTimerExpired == true)
        {
            isRTCTimerExpired = false;           
            LED1_Toggle();
            
            sprintf((char*)uartTxBuffer, "My Name is Calvin Ho %d F \r\n", SERCOM_LoopCounter++);
            status = SERCOM0_USART_Write(uartTxBuffer, strlen((const char*)uartTxBuffer));
            if (status == false)
            {
                /* Handle error condition */
            }
        }
  
    }

    /* Execution should not come here during normal operation */

    return ( EXIT_FAILURE );
}


/*******************************************************************************
 End of File
*/

